# Recruitee Connector
> Collaborative hiring software and modern applicant tracking system with easy setup, great UI, and top-rated customer support. Try free for 18 days!

🔗 https://recruitee.com/

| Actions |
| ------- |
| [**Pull jobs**](docs/pull_jobs.md) |
| [**Push profile**](docs/push_profile.md) |